@@ -519,7 +519,7 @@ class A3Behavior extends Behavior {
     }
     public final void moveForwardImmediately(double l) {
         Vector3d v = getUnitVecZ();
-        v.scale(-l);
+        v.scale(l);
         addLocImmediately(v);
     }
     public final void moveBackward(double l) {
@@ -529,7 +529,7 @@ class A3Behavior extends Behavior {
     }
     public final void moveBackwardImmediately(double l) {
         Vector3d v = getUnitVecZ();
-        v.scale(l);
+        v.scale(-l);
         addLocImmediately(v);
     }
     public final void moveRight(double l) {
@@ -572,6 +572,34 @@ class A3Behavior extends Behavior {
         v.scale(-l);
         addLocImmediately(v);
     }
+    public final void moveTo(Vector3d v, double l) {
+        Vector3d vv = new Vector3d();
+        vv.sub(v,nowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addLoc(vv);
+    }
+    public final void moveTo(double x, double y, double z, double l) {
+        Vector3d vv = new Vector3d(x,y,z);
+        vv.sub(nowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addLoc(vv);
+    }
+    public final void moveToImmediately(Vector3d v, double l) {
+        Vector3d vv = new Vector3d();
+        vv.sub(v,nowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addLocImmediately(vv);
+    }
+    public final void moveToImmediately(double x, double y, double z, double l) {
+        Vector3d vv = new Vector3d(x,y,z);
+        vv.sub(nowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addLocImmediately(vv);
+    }
 
     Vector3d getUnitVecX() {
         return Util.trans(nowQ,new Vector3d(1.0,0.0,0.0));
