@@ -228,6 +228,42 @@ public interface A3CanvasInterface {
      */
     public void moveCameraDownImmediately(double l);
 
+    /**
+     * カメラを指定した座標の方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public void moveCameraTo(Vector3d v, double l);
+
+    /**
+     * カメラを指定した座標の方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public void moveCameraTo(double x, double y, double z, double l);
+
+    /**
+     * カメラを指定したA3Objectの方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public void moveCameraTo(A3Object a, double l);
+
+    /**
+     * カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToImmediately(Vector3d v, double l);
+
+    /**
+     * カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToImmediately(double x, double y, double z, double l);
+
+    /**
+     * カメラを指定したA3Objectの方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToImmediately(A3Object a, double l);
+
     /**
      * シーンを指定して、カメラを前方に指定距離だけ移動します。
      */
@@ -288,6 +324,42 @@ public interface A3CanvasInterface {
      */
     public void moveCameraDownImmediately(double l,int scene);
 
+    /**
+     * シーンを指定して、カメラを指定した座標の方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public void moveCameraTo(Vector3d v, double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定した座標の方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public void moveCameraTo(double x, double y, double z, double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定したA3Objectの方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public void moveCameraTo(A3Object a, double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToImmediately(Vector3d v, double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToImmediately(double x, double y, double z, double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定したA3Objectの方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToImmediately(A3Object a, double l,int scene);
+
     /**
      * カメラの現在位置を返します。
      */
@@ -1315,7 +1387,8 @@ public interface A3CanvasInterface {
 
     /**
      * カメラの補間のスピードを調節するための係数を指定します。1.0から0.0の
-     * 間の数値を指定して下さい。小さいほど補間が速くなります。
+     * 間の数値を指定して下さい。小さいほど補間が速くなります。0.0に設定したら
+     * まったく補完されないようになります．
      * デフォルトは0.1です。
      */
     public void setCameraInterpolateRatio(double ir);
@@ -1368,4 +1441,350 @@ public interface A3CanvasInterface {
      * ライブラリ内部で仕様する物なので利用しないで下さい．
      */
     public A3VirtualUniverse getVirtualUniverse();
+
+    //################################################################################
+    //Now系メソッド．Immediatelyを呼ぶだけでOK．
+    //################################################################################
+
+    /**
+     * カメラの位置を即時に指定します。
+     */
+    public void setCameraLocNow(double x,double y,double z);
+
+    /**
+     * カメラの位置を即時に指定します。
+     */
+    public void setCameraLocNow(Vector3d loc);
+
+    /**
+     * 現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocNow(double x,double y,double z);
+
+    /**
+     * 現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocNow(Vector3d loc);
+
+    /**
+     * カメラを前方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraForwardNow(double l);
+
+    /**
+     * カメラを後方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraBackwardNow(double l);
+
+    /**
+     * カメラを右方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraRightNow(double l);
+
+    /**
+     * カメラを左方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraLeftNow(double l);
+
+    /**
+     * カメラを上方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraUpNow(double l);
+
+    /**
+     * カメラを下方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraDownNow(double l);
+
+    /**
+     * カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToNow(Vector3d v, double l);
+
+    /**
+     * カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToNow(double x, double y, double z, double l);
+
+    /**
+     * カメラを指定したA3Objectの方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToNow(A3Object a, double l);
+
+    /**
+     * シーンを指定して、カメラを前方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraForwardNow(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを後方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraBackwardNow(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを右方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraRightNow(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを左方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraLeftNow(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを上方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraUpNow(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを下方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraDownNow(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToNow(Vector3d v, double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToNow(double x, double y, double z, double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを指定したA3Objectの方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public void moveCameraToNow(A3Object a, double l,int scene);
+
+    /**
+     * カメラの回転を即時に指定します。
+     */
+    public void setCameraQuatNow(double x,double y,double z,double w);
+
+    /**
+     * カメラの回転を即時に指定します。
+     */
+    public void setCameraQuatNow(Quat4d quat);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatNow(double x,double y,double z,double w);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatNow(Quat4d quat);
+
+    /**
+     * カメラの回転を即時に指定します(オイラー角をラジアンで指定:x,y,z版)。
+     */
+    public void setCameraRotNow(double x,double y,double z);
+
+    /**
+     * カメラの回転を即時に指定します(オイラー角をラジアンで指定:Vector3d版)。
+     */
+    public void setCameraRotNow(Vector3d rot);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をラジアンで指定:x,y,z版)。
+     */
+    public void mulCameraRotNow(double x,double y,double z);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をラジアンで指定:Vector3d版)。
+     */
+    public void mulCameraRotNow(Vector3d rot);
+
+    /**
+     * カメラの回転を即時に指定します(オイラー角をデグリーで指定:x,y,z版)。
+     */
+    public void setCameraRevNow(double x,double y,double z);
+
+    /**
+     * カメラの回転を即時に指定します(オイラー角をデグリーで指定:Vector3d版)。
+     */
+    public void setCameraRevNow(Vector3d rev);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をデグリーで指定:x,y,z版)。
+     */
+    public void mulCameraRevNow(double x,double y,double z);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をデグリーで指定:Vector3d版)。
+     */
+    public void mulCameraRevNow(Vector3d rev);
+
+    /**
+     * カメラの拡大率を即時に指定します。拡大率がデフォルトの1.0の時は10cmより
+     * 手前と100mより奥はクリッピングされて表示されません。拡大率を0.1にすれば
+     * 1cmから10mの間を表示できるようになり、10.0にすれば1mから1kmの間を
+     * 表示できるようになります。
+     */
+    public void setCameraScaleNow(double s);
+
+    /**
+     * 現在のカメラの拡大率に引数で与えられた数値を掛け合せ新し拡大率として即時にセットします。
+     */
+    public void mulCameraScaleNow(double s);
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointNow(Vector3d lookAt);
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointNow(double x,double y,double z);
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(Vector3d lookAt,Vector3d up);
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(double x,double y,double z,Vector3d up);
+
+    /**
+     * シーンを指定して、カメラの位置を即時に指定します。
+     */
+    public void setCameraLocNow(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、カメラの位置を即時に指定します。
+     */
+    public void setCameraLocNow(Vector3d loc,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocNow(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocNow(Vector3d loc,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します。
+     */
+    public void setCameraQuatNow(double x,double y,double z,double w,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します。
+     */
+    public void setCameraQuatNow(Quat4d quat,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatNow(double x,double y,double z,double w,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatNow(Quat4d quat,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します(ラジアン版)。
+     */
+    public void setCameraRotNow(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します(ラジアン版)。
+     */
+    public void setCameraRotNow(Vector3d rot,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(ラジアン版)。
+     */
+    public void mulCameraRotNow(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(ラジアン版)。
+     */
+    public void mulCameraRotNow(Vector3d rot,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します(デグリー版)。
+     */
+    public void setCameraRevNow(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します(デグリー版)。
+     */
+    public void setCameraRevNow(Vector3d rev,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(デグリー版)。
+     */
+    public void mulCameraRevNow(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(デグリー版)。
+     */
+    public void mulCameraRevNow(Vector3d rev,int scene);
+
+    /**
+     * シーンを指定して、カメラの拡大率を即時に指定します。拡大率がデフォルトの1.0の時は10cmより
+     * 手前と100mより奥はクリッピングされて表示されません。拡大率を0.1にすれば
+     * 1cmから10mの間を表示できるようになり、10.0にすれば1mから1kmの間を
+     * 表示できるようになります。
+     */
+    public void setCameraScaleNow(double s,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの拡大率に引数で与えられた数値を掛け合せ新し拡大率として即時にセットします。
+     */
+    public void mulCameraScaleNow(double s,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointNow(Vector3d lookAt,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointNow(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(Vector3d lookAt,Vector3d up,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(double x,double y,double z,Vector3d up,int scene);
 }
