@@ -631,7 +631,7 @@ public abstract class A3Object {
     }
 
     /**
-     * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがx,y,zで
      * 指定した座標に向くように回転をセットします。その時の計算に
      * 使用する上方向ベクトルはgetUpperVector()で得られる物を
      * 使用します。
@@ -642,7 +642,7 @@ public abstract class A3Object {
     }
 
     /**
-     * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがx,y,zで
      * 指定した座標に向くように回転を即時にセットします。その時の計算に
      * 使用する上方向ベクトルはgetUpperVector()で得られる物を
      * 使用します。
@@ -652,6 +652,26 @@ public abstract class A3Object {
         behavior.setLookAtPointImmediately(lookAt);
     }
 
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それが引数で指定された
+     * A3Objectに向くように回転をセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPoint(A3Object a) {
+        behavior.setLookAtPoint(a.getLoc());
+    }
+
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それが引数で指定された
+     * A3Objectに向くように回転を即時にセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPointImmediately(A3Object a) {
+        behavior.setLookAtPointImmediately(a.getLoc());
+    }
+
     /**
      * 拡大率をセットするためのメソッド。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -1006,6 +1026,54 @@ public abstract class A3Object {
         behavior.moveDownImmediately(l);
     }
 
+    /**
+     * 指定した座標の方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public final void moveTo(Vector3d v, double l) {
+        behavior.moveTo(v,l);
+    }
+
+    /**
+     * 指定した座標の方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public final void moveTo(double x, double y, double z, double l) {
+        behavior.moveTo(x,y,z,l);
+    }
+
+    /**
+     * 指定したA3Objectの方向に指定距離だけ移動します。
+     * 回転はしません。
+     */
+    public final void moveTo(A3Object a, double l) {
+        behavior.moveTo(a.getLoc(),l);
+    }
+
+    /**
+     * 指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public final void moveToImmediately(Vector3d v, double l) {
+        behavior.moveToImmediately(v,l);
+    }
+
+    /**
+     * 指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public final void moveToImmediately(double x, double y, double z, double l) {
+        behavior.moveToImmediately(x,y,z,l);
+    }
+
+    /**
+     * 指定したA3Objectの方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public final void moveToImmediately(A3Object a, double l) {
+        behavior.moveToImmediately(a.getLoc(),l);
+    }
+
     /**
      * このオブジェクトのローカルな座標系のX軸がグローバルな
      * 仮想空間の座標系ではどちらの方向になるのかを返します。
@@ -1282,4 +1350,352 @@ public abstract class A3Object {
     protected void runInBehavior(Runnable r) {
         behavior.addRunnable(r);
     }
+
+    //################################################################################
+    //Now系メソッド．Immediately系メソッドとまったく同じ処理
+    //################################################################################
+
+    /**
+     * 位置、回転、拡大率を同時に、即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveNow(Vector3d v, Quat4d q, double s) {
+        behavior.moveImmediately(v,q,s);
+    }
+
+    /**
+     * 位置、回転、拡大率を同時に、即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 引数rotはx軸、y軸、z軸の回転からなるベクトルです。
+     */
+    public final void moveNow(Vector3d loc, Vector3d rot, double scale) {
+        moveImmediately(loc,Util.euler2quat(rot),scale);
+    }
+
+    /**
+     * 位置を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setLocNow(Vector3d v) {
+        behavior.setLocImmediately(v);
+    }
+
+    /**
+     * 位置を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setLocNow(double x,double y,double z) {
+        setLocImmediately(new Vector3d(x,y,z));
+    }
+
+    /**
+     * 現在位置に引数で与えたベクトルを加えて新しい現在位置を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void addLocNow(Vector3d v) {
+        behavior.addLocImmediately(v);
+    }
+
+    /**
+     * 現在位置に引数で与えたベクトルを加えて新しい現在位置を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void addLocNow(double x,double y,double z) {
+        addLocImmediately(new Vector3d(x,y,z));
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(四元数:Quad4d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setQuatNow(Quat4d q) {
+        behavior.setQuatImmediately(q);
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(四元数:x,y,z,w版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setQuatNow(double x,double y,double z,double w) {
+        setQuatImmediately(new Quat4d(x,y,z,w));
+    }
+
+    /**
+     * 現在の回転に引数で与えた回転を即座に合成するメソッド(四元数:Quad4d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulQuatNow(Quat4d q) {
+        behavior.mulQuatImmediately(q);
+    }
+
+    /**
+     * 現在の回転に引数で与えた回転を即座に合成するメソッド(四元数:x,y,z,w版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulQuatNow(double x,double y,double z,double w) {
+        setQuatImmediately(new Quat4d(x,y,z,w));
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(オイラー角:Vector3d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRotNow(Vector3d rot) {
+        setQuatImmediately(Util.euler2quat(rot));
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(オイラー角:x,y,z版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRotNow(double x,double y,double z) {
+        setQuatImmediately(Util.euler2quat(x,y,z));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角:Vector3d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRotNow(Vector3d rot) {
+        mulQuatImmediately(Util.euler2quat(rot));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角:x,y,z版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRotNow(double x,double y,double z) {
+        mulQuatImmediately(Util.euler2quat(x,y,z));
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRevNow(Vector3d rev) {
+        setQuatImmediately(Util.euler2quat(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z));
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(オイラー角をデグリーで指定:x,y,z版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRevNow(double x,double y,double z) {
+        setQuatImmediately(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRevNow(Vector3d rev) {
+        mulQuatImmediately(Util.euler2quat(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角をデグリーで指定:x,y,z版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRevNow(double x,double y,double z) {
+        mulQuatImmediately(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
+    }
+
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
+     * 指定した座標に向くように回転を即時にセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPointNow(Vector3d lookAt) {
+        behavior.setLookAtPointImmediately(lookAt);
+    }
+
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがx,y,zで
+     * 指定した座標に向くように回転を即時にセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPointNow(double x,double y,double z) {
+        Vector3d lookAt = new Vector3d(x,y,z);
+        behavior.setLookAtPointImmediately(lookAt);
+    }
+
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それが引数で指定された
+     * A3Objectに向くように回転を即時にセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPointNow(A3Object a) {
+        behavior.setLookAtPointImmediately(a.getLoc());
+    }
+
+    /**
+     * 拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleNow(double s) {
+        behavior.setScaleImmediately(s);
+    }
+
+    /**
+     * 現在の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleNow(double s) {
+        behavior.mulScaleImmediately(s);
+    }
+
+    /**
+     * X軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleXNow(double sx) {
+        behavior.setScaleXImmediately(sx);
+    }
+
+    /**
+     * Y軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleYNow(double sy) {
+        behavior.setScaleYImmediately(sy);
+    }
+
+    /**
+     * Z軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleZNow(double sz) {
+        behavior.setScaleZImmediately(sz);
+    }
+
+    /**
+     * X,Y,Z軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleNow(Vector3d sv) {
+        behavior.setScaleImmediately(sv);
+    }
+
+    /**
+     * 現在のX軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleXNow(double sx) {
+        behavior.mulScaleXImmediately(sx);
+    }
+
+    /**
+     * 現在のY軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleYNow(double sy) {
+        behavior.mulScaleYImmediately(sy);
+    }
+
+    /**
+     * 現在のZ軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleZNow(double sz) {
+        behavior.mulScaleZImmediately(sz);
+    }
+
+    /**
+     * 現在のX,Y,Z軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleNow(Vector3d sv) {
+        behavior.mulScaleImmediately(sv);
+    }
+
+    /**
+     * 正面方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveForwardNow(double l) {
+        behavior.moveForwardImmediately(l);
+    }
+
+    /**
+     * 後ろ方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveBackwardNow(double l) {
+        behavior.moveBackwardImmediately(l);
+    }
+
+    /**
+     * 右方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveRightNow(double l) {
+        behavior.moveRightImmediately(l);
+    }
+
+    /**
+     * 左方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveLeftNow(double l) {
+        behavior.moveLeftImmediately(l);
+    }
+
+    /**
+     * 上方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveUpNow(double l) {
+        behavior.moveUpImmediately(l);
+    }
+
+    /**
+     * 下方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveDownNow(double l) {
+        behavior.moveDownImmediately(l);
+    }
+
+    /**
+     * 指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public final void moveToNow(Vector3d v, double l) {
+        behavior.moveToImmediately(v,l);
+    }
+
+    /**
+     * 指定した座標の方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public final void moveToNow(double x, double y, double z, double l) {
+        behavior.moveToImmediately(x,y,z,l);
+    }
+
+    /**
+     * 指定したA3Objectの方向に指定距離だけ即時に移動します。
+     * 回転はしません。
+     */
+    public final void moveToNow(A3Object a, double l) {
+        behavior.moveToImmediately(a.getLoc(),l);
+    }
 }
