@@ -233,7 +233,7 @@ public class A3Screen implements A3CanvasInterface {
     public void addCameraLocImmediately(Vector3d loc) {
         canvas.addCameraLocImmediately(loc);
     }
-//gaha;
+
     @Override
     public void moveCameraForward(double l) {
         canvas.moveCameraForward(l);
@@ -294,6 +294,36 @@ public class A3Screen implements A3CanvasInterface {
         canvas.moveCameraDownImmediately(l);
     }
 
+    @Override
+    public void moveCameraTo(Vector3d v, double l) {
+        canvas.moveCameraTo(v,l);
+    }
+
+    @Override
+    public void moveCameraTo(double x, double y, double z, double l) {
+        canvas.moveCameraTo(x,y,z,l);
+    }
+
+    @Override
+    public void moveCameraTo(A3Object a, double l) {
+        canvas.moveCameraTo(a,l);
+    }
+
+    @Override
+    public void moveCameraToImmediately(Vector3d v, double l) {
+        canvas.moveCameraToImmediately(v,l);
+    }
+
+    @Override
+    public void moveCameraToImmediately(double x, double y, double z, double l) {
+        canvas.moveCameraToImmediately(x,y,z,l);
+    }
+
+    @Override
+    public void moveCameraToImmediately(A3Object a, double l) {
+        canvas.moveCameraToImmediately(a,l);
+    }
+
     @Override
     public void moveCameraForward(double l,int scene) {
         canvas.moveCameraForward(l,scene);
@@ -353,7 +383,37 @@ public class A3Screen implements A3CanvasInterface {
     public void moveCameraDownImmediately(double l,int scene) {
         canvas.moveCameraDownImmediately(l,scene);
     }
-//gaha;
+
+    @Override
+    public void moveCameraTo(Vector3d v, double l, int scene) {
+        canvas.moveCameraTo(v,l,scene);
+    }
+
+    @Override
+    public void moveCameraTo(double x, double y, double z, double l, int scene) {
+        canvas.moveCameraTo(x,y,z,l,scene);
+    }
+
+    @Override
+    public void moveCameraTo(A3Object a, double l, int scene) {
+        canvas.moveCameraTo(a,l,scene);
+    }
+
+    @Override
+    public void moveCameraToImmediately(Vector3d v, double l, int scene) {
+        canvas.moveCameraToImmediately(v,l,scene);
+    }
+
+    @Override
+    public void moveCameraToImmediately(double x, double y, double z, double l, int scene) {
+        canvas.moveCameraToImmediately(x,y,z,l,scene);
+    }
+
+    @Override
+    public void moveCameraToImmediately(A3Object a, double l, int scene) {
+        canvas.moveCameraToImmediately(a,l,scene);
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return canvas.getCameraLoc();
@@ -750,7 +810,7 @@ public class A3Screen implements A3CanvasInterface {
 
     @Override
     public void del(A3Object a,int s) {
-        canvas.add(a,s);
+        canvas.del(a,s);
     }
 
     @Override
@@ -1285,4 +1345,257 @@ public class A3Screen implements A3CanvasInterface {
     public A3VirtualUniverse getVirtualUniverse() {
         return canvas.getVirtualUniverse();
     }
+
+    //################################################################################
+    //Now系メソッド．Immediatelyを呼ぶだけでOK．
+    //################################################################################
+    @Override
+    public void setCameraLocNow(double x,double y,double z) {
+        setCameraLocImmediately(x,y,z);
+    }
+    @Override
+    public void setCameraLocNow(Vector3d loc) {
+        setCameraLocImmediately(loc);
+    }
+    @Override
+    public void addCameraLocNow(double x,double y,double z) {
+        addCameraLocImmediately(x,y,z);
+    }
+    @Override
+    public void addCameraLocNow(Vector3d loc) {
+        addCameraLocImmediately(loc);
+    }
+    @Override
+    public void moveCameraForwardNow(double l) {
+        moveCameraForwardImmediately(l);
+    }
+    @Override
+    public void moveCameraBackwardNow(double l) {
+        moveCameraBackwardImmediately(l);
+    }
+    @Override
+    public void moveCameraRightNow(double l) {
+        moveCameraRightImmediately(l);
+    }
+    @Override
+    public void moveCameraLeftNow(double l) {
+        moveCameraLeftImmediately(l);
+    }
+    @Override
+    public void moveCameraUpNow(double l) {
+        moveCameraUpImmediately(l);
+    }
+    @Override
+    public void moveCameraDownNow(double l) {
+        moveCameraDownImmediately(l);
+    }
+    @Override
+    public void moveCameraToNow(Vector3d v, double l) {
+        moveCameraToImmediately(v, l);
+    }
+    @Override
+    public void moveCameraToNow(double x, double y, double z, double l) {
+        moveCameraToImmediately(x, y, z, l);
+    }
+    @Override
+    public void moveCameraToNow(A3Object a, double l) {
+        moveCameraToImmediately(a, l);
+    }
+    @Override
+    public void moveCameraForwardNow(double l,int scene) {
+        moveCameraForwardImmediately(l,scene);
+    }
+    @Override
+    public void moveCameraBackwardNow(double l,int scene) {
+        moveCameraBackwardImmediately(l,scene);
+    }
+    @Override
+    public void moveCameraRightNow(double l,int scene) {
+        moveCameraRightImmediately(l,scene);
+    }
+    @Override
+    public void moveCameraLeftNow(double l,int scene) {
+        moveCameraLeftImmediately(l,scene);
+    }
+    @Override
+    public void moveCameraUpNow(double l,int scene) {
+        moveCameraUpImmediately(l,scene);
+    }
+    @Override
+    public void moveCameraDownNow(double l,int scene) {
+        moveCameraDownImmediately(l,scene);
+    }
+    @Override
+    public void moveCameraToNow(Vector3d v, double l,int scene) {
+        moveCameraToImmediately(v, l,scene);
+    }
+    @Override
+    public void moveCameraToNow(double x, double y, double z, double l,int scene) {
+        moveCameraToImmediately(x, y, z, l,scene);
+    }
+    @Override
+    public void moveCameraToNow(A3Object a, double l,int scene) {
+        moveCameraToImmediately(a, l,scene);
+    }
+    @Override
+    public void setCameraQuatNow(double x,double y,double z,double w) {
+        setCameraQuatImmediately(x,y,z,w);
+    }
+    @Override
+    public void setCameraQuatNow(Quat4d quat) {
+        setCameraQuatImmediately(quat);
+    }
+    @Override
+    public void mulCameraQuatNow(double x,double y,double z,double w) {
+        mulCameraQuatImmediately(x,y,z,w);
+    }
+    @Override
+    public void mulCameraQuatNow(Quat4d quat) {
+        mulCameraQuatImmediately(quat);
+    }
+    @Override
+    public void setCameraRotNow(double x,double y,double z) {
+        setCameraRotImmediately(x,y,z);
+    }
+    @Override
+    public void setCameraRotNow(Vector3d rot) {
+        setCameraRotImmediately(rot);
+    }
+    @Override
+    public void mulCameraRotNow(double x,double y,double z) {
+        mulCameraRotImmediately(x,y,z);
+    }
+    @Override
+    public void mulCameraRotNow(Vector3d rot) {
+        mulCameraRotImmediately(rot);
+    }
+    @Override
+    public void setCameraRevNow(double x,double y,double z) {
+        setCameraRevImmediately(x,y,z);
+    }
+    @Override
+    public void setCameraRevNow(Vector3d rev) {
+        setCameraRevImmediately(rev);
+    }
+    @Override
+    public void mulCameraRevNow(double x,double y,double z) {
+        mulCameraRevImmediately(x,y,z);
+    }
+    @Override
+    public void mulCameraRevNow(Vector3d rev) {
+        mulCameraRevImmediately(rev);
+    }
+    @Override
+    public void setCameraScaleNow(double s) {
+        setCameraScaleImmediately(s);
+    }
+    @Override
+    public void mulCameraScaleNow(double s) {
+        mulCameraScaleImmediately(s);
+    }
+    @Override
+    public void setCameraLookAtPointNow(Vector3d lookAt) {
+        setCameraLookAtPointImmediately(lookAt);
+    }
+    @Override
+    public void setCameraLookAtPointNow(double x,double y,double z) {
+        setCameraLookAtPointImmediately(x,y,z);
+    }
+    @Override
+    public void setCameraLookAtPointNow(Vector3d lookAt,Vector3d up) {
+        setCameraLookAtPointImmediately(lookAt,up);
+    }
+    @Override
+    public void setCameraLookAtPointNow(double x,double y,double z,Vector3d up) {
+        setCameraLookAtPointImmediately(x,y,z,up);
+    }
+    @Override
+    public void setCameraLocNow(double x,double y,double z,int scene) {
+        setCameraLocImmediately(x,y,z,scene);
+    }
+    @Override
+    public void setCameraLocNow(Vector3d loc,int scene) {
+        setCameraLocImmediately(loc,scene);
+    }
+    @Override
+    public void addCameraLocNow(double x,double y,double z,int scene) {
+        addCameraLocImmediately(x,y,z,scene);
+    }
+    @Override
+    public void addCameraLocNow(Vector3d loc,int scene) {
+        addCameraLocImmediately(loc,scene);
+    }
+    @Override
+    public void setCameraQuatNow(double x,double y,double z,double w,int scene) {
+        setCameraQuatImmediately(x,y,z,w,scene);
+    }
+    @Override
+    public void setCameraQuatNow(Quat4d quat,int scene) {
+        setCameraQuatImmediately(quat,scene);
+    }
+    @Override
+    public void mulCameraQuatNow(double x,double y,double z,double w,int scene) {
+        mulCameraQuatImmediately(x,y,z,w,scene);
+    }
+    @Override
+    public void mulCameraQuatNow(Quat4d quat,int scene) {
+        mulCameraQuatImmediately(quat,scene);
+    }
+    @Override
+    public void setCameraRotNow(double x,double y,double z,int scene) {
+        setCameraRotImmediately(x,y,z,scene);
+    }
+    @Override
+    public void setCameraRotNow(Vector3d rot,int scene) {
+        setCameraRotImmediately(rot,scene);
+    }
+    @Override
+    public void mulCameraRotNow(double x,double y,double z,int scene) {
+        mulCameraRotImmediately(x,y,z,scene);
+    }
+    @Override
+    public void mulCameraRotNow(Vector3d rot,int scene) {
+        mulCameraRotImmediately(rot,scene);
+    }
+    @Override
+    public void setCameraRevNow(double x,double y,double z,int scene) {
+        setCameraRevImmediately(x,y,z,scene);
+    }
+    @Override
+    public void setCameraRevNow(Vector3d rev,int scene) {
+        setCameraRevImmediately(rev,scene);
+    }
+    @Override
+    public void mulCameraRevNow(double x,double y,double z,int scene) {
+        mulCameraRevImmediately(x,y,z,scene);
+    }
+    @Override
+    public void mulCameraRevNow(Vector3d rev,int scene) {
+        mulCameraRevImmediately(rev,scene);
+    }
+    @Override
+    public void setCameraScaleNow(double s,int scene) {
+        setCameraScaleImmediately(s,scene);
+    }
+    @Override
+    public void mulCameraScaleNow(double s,int scene) {
+        mulCameraScaleImmediately(s,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(Vector3d lookAt,int scene) {
+        setCameraLookAtPointImmediately(lookAt,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(double x,double y,double z,int scene) {
+        setCameraLookAtPointImmediately(x,y,z,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(Vector3d lookAt,Vector3d up,int scene) {
+        setCameraLookAtPointImmediately(lookAt,up,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(double x,double y,double z,Vector3d up,int scene) {
+        setCameraLookAtPointImmediately(x,y,z,up,scene);
+    }
+
 }
