@@ -27,16 +27,23 @@ public class Action3D extends A3Object implements ActionObject {
      * URL文字列が示すAcerola3Dファイルを読み込みAction3D
      * のインスタンスを生成します。
      */
-    public synchronized static Action3D load(String a3URL) throws Exception {
+    public synchronized static Action3D load(String a3URL) {
         A23.initA23();
-        return load(new URL(a3URL));
+        Action3D tmpA3 = null;
+        try {
+            tmpA3 = load(new URL(a3URL));
+        } catch(Exception e) {
+            e.printStackTrace();
+            tmpA3 = load("x-res:///jp/sourceforge/acerola3d/resources/error.a3");
+        }
+        return tmpA3;
     }
 
     /**
      * URLオブジェクトが示すAcerola3Dファイルを読み込みAction3D
      * のインスタンスを生成します。
      */
-    public synchronized static Action3D load(URL a3URL) throws Exception {
+    public synchronized static Action3D load(URL a3URL) {
         A23.initA23();
         initAction3D();
 
@@ -69,7 +76,7 @@ public class Action3D extends A3Object implements ActionObject {
      * <tr><td>7:boolean     </td><td>billboard       </td><td>任意</td></tr>
      * </table>
      */
-    public Action3D(A3InitData d) throws Exception {
+    public Action3D(A3InitData d) {
         super(d);
         realConstructor(d);
     }
@@ -78,7 +85,7 @@ public class Action3D extends A3Object implements ActionObject {
      * コンストラクタ。このコンストラクタで指定できるのはURLだけなので
      * 他の設定はオブジェクト生成後に各種メソッドで指定して下さい。
      */
-    public Action3D(String a3URL) throws Exception {
+    public Action3D(String a3URL) {
         super(initHack());
         A3InitData d = new A3InitData("jp.sourceforge.acerola3d.a3.Action3D");
         d.set(a3URL,-1);
@@ -89,7 +96,7 @@ public class Action3D extends A3Object implements ActionObject {
      * コンストラクタ。このコンストラクタで指定できるのはURLだけなので
      * 他の設定はオブジェクト生成後に各種メソッドで指定して下さい。
      */
-    public Action3D(URL a3URL) throws Exception {
+    public Action3D(URL a3URL) {
         super(initHack());
         A3InitData d = new A3InitData("jp.sourceforge.acerola3d.a3.Action3D");
         d.set(a3URL,-1);
@@ -98,39 +105,46 @@ public class Action3D extends A3Object implements ActionObject {
     static A3InitData initHack() {
         return new A3InitData("jp.sourceforge.acerola3d.a3.Action3D");
     }
-    void realConstructor(A3InitData d) throws Exception {
-        A23.initA23();
-        initAction3D();
-        URL url = null;
-        if (d.get(0) instanceof String)
-            url = new URL(d.getString(0));
-        else if (d.get(0) instanceof URL)
-            url = d.getURL(0);
-        Action3DData action3DData = action3DDataCash.get(url);
-        if (action3DData==null) {
-            action3DData = new Action3DData(url);
-            action3DDataCash.put(url,action3DData);
-        }
-        if (action3DData.billboardControl) {
-            setEnableBehavior(true);
-            setBillboardControl(true);
-        }
-        actionBehavior = new ActionBehavior(this,action3DData.copy());
-        setNode(actionBehavior.getNode());
+    void realConstructor(A3InitData d) {
+        try {
+            A23.initA23();
+            initAction3D();
+            URL url = null;
+            if (d.get(0) instanceof String)
+                url = new URL(d.getString(0));
+            else if (d.get(0) instanceof URL)
+                url = d.getURL(0);
+            Action3DData action3DData = action3DDataCash.get(url);
+            if (action3DData==null) {
+                action3DData = new Action3DData(url);
+                action3DDataCash.put(url,action3DData);
+            }
+            if (action3DData.billboardControl) {
+                setEnableBehavior(true);
+                setBillboardControl(true);
+            }
+            actionBehavior = new ActionBehavior(this,action3DData.copy());
+            setNode(actionBehavior.getNode());
 
-        actionBehavior.initAction(d.get(1));
-        if (d.getDataCount()>=5) {
-            setHaltAction(d.get(2));
-            setWalkAction(d.get(3));
-            setRunAction(d.get(4));
-            setAutoActionControl(true);
-        }
-        if (d.getDataCount()>=7) {
-            setMinWalkSpeed(d.getDouble(5));
-            setMinRunSpeed(d.getDouble(6));
-        }
-        if (d.getDataCount()>=8) {
-            setBillboardControl(d.getBoolean(7));
+            actionBehavior.initAction(d.get(1));
+            if (d.getDataCount()>=5) {
+                setHaltAction(d.get(2));
+                setWalkAction(d.get(3));
+                setRunAction(d.get(4));
+                setAutoActionControl(true);
+            }
+            if (d.getDataCount()>=7) {
+                setMinWalkSpeed(d.getDouble(5));
+                setMinRunSpeed(d.getDouble(6));
+            }
+            if (d.getDataCount()>=8) {
+                setBillboardControl(d.getBoolean(7));
+            }
+        } catch (Exception e) {
+            e.printStackTrace();
+            d = new A3InitData("jp.sourceforge.acerola3d.a3.Action3D");
+            d.set("x-res:///jp/sourceforge/acerola3d/resources/error.a3",-1);
+            realConstructor(d);
         }
     }
 
@@ -200,6 +214,27 @@ public class Action3D extends A3Object implements ActionObject {
         actionBehavior.changeImmediately(s);
     }
 
+    /**
+     * 指定したアクションナンバーのアクションに即座に
+     * 切りかえます。待ち行列に他のアクションの切りかえ要求が
+     * 残っていても、それらを無視して指定したアクションに切りかえます。
+     */
+    public void changeNow(int newActionNo) {
+        actionBehavior.changeImmediately(newActionNo);
+    }
+
+    /**
+     * 指定したアクションに即座に切りかえます。待ち行列に
+     * 他のアクションの切りかえ要求が残っていても、それらを
+     * 無視して指定したアクションに切りかえます。
+     * 引数がStringであれば、アクション名と見なし、
+     * Integerである場合はアクションナンバーであると見なし、
+     * アクションを切り替えます。
+     */
+    public void changeNow(Serializable s) {
+        actionBehavior.changeImmediately(s);
+    }
+
     /**
      * このAction3Dに含まれるアクションの個数を返します。
      */
@@ -505,6 +540,52 @@ public class Action3D extends A3Object implements ActionObject {
         actionBehavior.setShape(action,boneName,shape);
     }
 
+    /**
+     * このAction3Dで使用されている全てのShapeのファイル名を
+     * 返す．同じShapeが異なるBoneやActionで共有されている場合でも，
+     * 返り値は重複しないようになっている．
+     */
+    public String[] getShapeFilenames() {
+        return actionBehavior.getShapeFilenames();
+    }
+
+    /**
+     * このAction3Dで使用されていShapeをファイル名で指定し，
+     * そのShapeを引数で指定されたJava3DのNodeに変更します．
+     * 変更前のShapeが異なるBoneやActionで共有されている場合には
+     * その全てをnodeに置き換えます．この置き換えにはSharedGroupと
+     * Linkを使った実装が使われます．なのでVRML.getNode()や
+     * Action3D.getNode()は使えません。Util.loadVRML_B()を
+     * 使用して下さ。
+     */
+    public void replaceShape(String shapeFilename,Node node) {
+        actionBehavior.replaceShape(shapeFilename,node);
+    }
+
+    /**
+     * このAction3Dで使用されていShapeをファイル名で指定し，
+     * そのShapeを引数で指定されたURLから生成されるAction3Dの
+     * getNode()メソッドで得られるNodeで置き換えます．
+     * 変更前のShapeが異なるBoneやActionで共有されている場合には
+     * その全てを置き換えます．この置き換えの実装では，内部で
+     * 置き換えが必要なShapeの数だけAction3DがnewされてShapeごとに
+     * 独立したAction3Dがセットされます．これらの複数のAction3Dの
+     * Actionのchangeを一括して行うためにはshapeChange()メソッドを
+     * 使用して下さい．
+     */
+    public void replaceShapeWithA3(String shapeFilename,String a3url) throws Exception {
+        actionBehavior.replaceShapeWithA3(shapeFilename,a3url);
+    }
+
+    /**
+     * ファイル名で指定したShapeがreplaceShapeWithA3()で変更されている
+     * 場合に，そのメソッドの中で生成される全てのAction3Dのアクションを
+     * 一括で変更します．
+     */
+    public void shapeChange(String shapeFilename,String actionName) {
+        actionBehavior.shapeChange(shapeFilename,actionName);
+    }
+
     /**
      * Soundをアクションに設定。
      * まだ未実装。
@@ -734,6 +815,13 @@ public class Action3D extends A3Object implements ActionObject {
         }
         setBalloonLoc(actionNo,d,x,y);
     }
+    /**
+     * 全てのアクションにおいて、指定した向きの吹き出しを表示する場合のオフセットを設定します。
+     */
+    public void setBalloonLocAll(A3Object.BalloonDir d,double x,double y) {
+        setBalloonLoc(d,x,y);
+        actionBehavior.setBalloonLocAll(d,x,y);
+    }
     /**
      * 向きを指定して吹き出しを表示する場合のオフセットを返します。
      */
@@ -797,6 +885,13 @@ public class Action3D extends A3Object implements ActionObject {
         }
         setBalloonDir(actionNo,d);
     }
+    /**
+     * 全てのアクションの吹き出しを表示する場合の向きを設定します。
+     */
+    public void setBalloonDirAll(BalloonDir d) {
+        setBalloonDir(d);
+        actionBehavior.setBalloonDirAll(d);
+    }
     //----------------------------------------
     void setSoundLocQuat(Vector3d v,Quat4d q) {
         if (actionBehavior!=null)
