@@ -428,6 +428,37 @@ class Scene implements Component2DContainerInterface {
         addCameraLocImmediately(v);
     }
     
+    public void moveCameraTo(Vector3d v, double l) {
+        Vector3d vv = new Vector3d();
+        vv.sub(v,cameraNowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addCameraLoc(vv);
+    }
+
+    public void moveCameraTo(double x, double y, double z, double l) {
+        Vector3d vv = new Vector3d(x,y,z);
+        vv.sub(cameraNowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addCameraLoc(vv);
+    }
+
+    public void moveCameraToImmediately(Vector3d v, double l) {
+        Vector3d vv = new Vector3d();
+        vv.sub(v,cameraNowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addCameraLocImmediately(vv);
+    }
+
+    public void moveCameraToImmediately(double x, double y, double z, double l) {
+        Vector3d vv = new Vector3d(x,y,z);
+        vv.sub(cameraNowV);
+        if (vv.length()!=0.0) vv.normalize();
+        vv.scale(l);
+        addCameraLocImmediately(vv);
+    }
 
     /**
      * カメラの現在位置を返します。
