@@ -267,6 +267,29 @@ class SubCameraBehavior extends Behavior {
         addCameraLocImmediately(v);
     }
 
+    public void moveCameraTo(Vector3d v, double l) {
+        Vector3d vv = new Vector3d();
+        vv.sub(v,cameraNowV);
+        addCameraLoc(vv);
+    }
+
+    public void moveCameraTo(double x, double y, double z, double l) {
+        Vector3d vv = new Vector3d(x,y,z);
+        vv.sub(cameraNowV);
+        addCameraLoc(vv);
+    }
+
+    public void moveCameraToImmediately(Vector3d v, double l) {
+        Vector3d vv = new Vector3d();
+        vv.sub(v,cameraNowV);
+        addCameraLocImmediately(vv);
+    }
+
+    public void moveCameraToImmediately(double x, double y, double z, double l) {
+        Vector3d vv = new Vector3d(x,y,z);
+        vv.sub(cameraNowV);
+        addCameraLocImmediately(vv);
+    }
 
     /**
      * カメラの現在位置を返します。
