@@ -1,7 +1,7 @@
 package jp.sourceforge.acerola3d.sound;
 
-import net.java.games.joal.*;
-import net.java.games.joal.util.*;
+import com.jogamp.openal.*;
+import com.jogamp.openal.util.*;
 import javax.vecmath.*;
 import java.util.*;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
@@ -21,17 +21,22 @@ public class A3SoundSystem {
     }
 
     A3SoundSystem() {
-        //ALut.alutInit();
-        ALC alc = ALFactory.getALC();
-        ALCdevice device = alc.alcOpenDevice(null);
-        if (device!=null) {
-            ALCcontext context = alc.alcCreateContext(device, null);
-            if (context!=null) {
-                alc.alcMakeContextCurrent(context);
+        try {
+            //ALut.alutInit();
+            ALC alc = ALFactory.getALC();
+            ALCdevice device = alc.alcOpenDevice(null);
+            if (device!=null) {
+                ALCcontext context = alc.alcCreateContext(device, null);
+                if (context!=null) {
+                    alc.alcMakeContextCurrent(context);
+                }
             }
+            al = ALFactory.getAL();
+            al.alGetError();
+        } catch(Exception e) {
+            e.printStackTrace();
+            return;
         }
-        al = ALFactory.getAL();
-        al.alGetError();
 
         //距離による減衰の計算方法
         //al.alDistanceModel(AL.AL_EXPONENT_DISTANCE);
@@ -68,9 +73,11 @@ public class A3SoundSystem {
         return newSound;
     }
     public void setListenerLoc(float x,float y,float z) {
+        if (al==null) return;
         al.alListener3f(AL.AL_POSITION,x,y,z);
     }
     public void setListenerLoc(Vector3d l) {
+        if (al==null) return;
         al.alListener3f(AL.AL_POSITION,(float)l.x,(float)l.y,(float)l.z);
     }
     public void setListenerRot(float x,float y,float z) {
@@ -90,6 +97,7 @@ public class A3SoundSystem {
         setListenerRot(x,y,z);
     }
     public void setListenerQuat(Quat4d q) {
+        if (al==null) return;
         Quat4d qTmp = new Quat4d(0.0,0.0,-1.0,0.0);
         Quat4d qq = new Quat4d(q);
         Quat4d qc = new Quat4d(q);
@@ -110,19 +118,24 @@ public class A3SoundSystem {
         al.alListenerfv(AL.AL_ORIENTATION,lookAtAndUp,0);
     }
     public void setListenerVel(float x,float y,float z) {
+        if (al==null) return;
         al.alListener3f(AL.AL_VELOCITY,x,y,z);
     }
     public void setListenerVel(Vector3d v) {
+        if (al==null) return;
         al.alListener3f(AL.AL_VELOCITY,(float)v.x,(float)v.y,(float)v.z);
     }
     public Vector3d getListenerVel() {
+        if (al==null) return null;
         // TODO
         return null;
     }
     public void setListenerGain(double g) {
+        if (al==null) return;
         al.alListenerf(AL.AL_GAIN,(float)g);
     }
     public double getListenerGain() {
+        if (al==null) return -1.0;
         float f[] = new float[1];
         al.alGetListenerf(AL.AL_GAIN,f,0);
         return f[0];
